MethodChannelTestNative class

An implementation of SwRendPlatform that uses method channels.

Inheritance

Constructors

MethodChannelTestNative()

Properties

hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
The method channel used to interact with the native platform.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose(int texId) → Future<void>
override
draw(int texId, int x, int y, int w, int h, Uint8List pixels) → Future<void>
override
getPixels(int texId) → Future<Uint8List?>
override
getSize(int texId) → Future<Int32List?>
override
init(int w, int h) → Future<int?>
override
invalidate(int texId) → Future<void>
override
listTextures() → Future<Int64List?>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited