SwRendPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • SwRendPlatform
Implementers

Constructors

SwRendPlatform()
Constructs a TestNativePlatform.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose(int texId) → Future<void>
draw(int texId, int x, int y, int w, int h, Uint8List pixels) → Future<void>
getPixels(int texId) → Future<Uint8List?>
getSize(int texId) → Future<Int32List?>
init(int w, int h) → Future<int?>
invalidate(int texId) → Future<void>
listTextures() → Future<Int64List?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ SwRendPlatform
The default instance of SwRendPlatform to use.
getter/setter pair